@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# $Id: owfs.py 1377 2015-10-27 22:32:30Z mwall $
+# $Id: owfs.py 1378 2015-10-28 05:17:10Z mwall $
 #
 # Copyright 2013 Matthew Wall
 # Thanks to Mark Cressey (onewireweewx) and Howard Walter (TAI code).
@@ -170,7 +170,7 @@ from weewx.drivers import AbstractDevice
 from weewx.engine import StdService
 
 DRIVER_NAME = 'OWFS'
-DRIVER_VERSION = "0.16"
+DRIVER_VERSION = "0.17"
 
 def logmsg(level, msg):
     syslog.syslog(level, 'owfs: %s' % msg)
@@ -596,7 +596,12 @@ if __name__ == '__main__':
             elif k.startswith('_'):
                 print '%s%s: %s' % ('  '*level, k, d[k])
             else:
-                print '%s%s: %s' % ('  '*level, d[k], ow.owfs_get(d[k]))
+                v = 'UNKNOWN'
+                try:
+                    v = ow.owfs_get(d[k])
+                except ow.exError, e:
+                    v = 'FAIL: %s' % e
+                print '%s%s: %s' % ('  '*level, d[k], v)
 
     def traverse(device, func):
         for s in device.sensors():
